#ifndef ACCOUNTDIALOG_H
#define ACCOUNTDIALOG_H

/*
 * autor 
 * Micha Podsiadlik
 * michal at gov.one.pl
 */

#include <qdialog.h>
#include <qgrid.h>
#include <qlineedit.h>
#include <qspinbox.h>
#include <qpushbutton.h>
#include <qcombobox.h>

#include "debug.h"

#include "pop3.h"

class AccountDialog: public QDialog
{
	Q_OBJECT

	public:
		AccountDialog(Pop3Proto* acc);

	private:
		QGrid *layout;
		QLineEdit *name, *host, *user, *password;
		QSpinBox *port;
		QPushButton *ok, *cancel;
		QComboBox *conntype;
		Pop3Proto *Acc;

	private slots:
		void save();		

	protected:
		virtual void resizeEvent(QResizeEvent* e);
};

#endif

